==> zio-aws-schemas_2.13-5.17.115.1-sources.jar: zio/aws/schemas/model/ListDiscoverersRequest.scala <==
package zio.aws.schemas.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters._
final case class ListDiscoverersRequest(
    discovererIdPrefix: Option[__string] = None,
    limit: Option[__integer] = None,
    nextToken: Option[__string] = None,
    sourceArnPrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest = {
    import ListDiscoverersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
      .builder()
      .optionallyWith(
        discovererIdPrefix.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.discovererIdPrefix)
      .optionallyWith(limit.map(value => __integer.unwrap(value): Integer))(
        _.limit
      )
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        sourceArnPrefix.map(value => __string.unwrap(value): java.lang.String)
      )(_.sourceArnPrefix)
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly =
    zio.aws.schemas.model.ListDiscoverersRequest.wrap(buildAwsValue())
}
object ListDiscoverersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.ListDiscoverersRequest =
      zio.aws.schemas.model.ListDiscoverersRequest(
        discovererIdPrefix.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value),
        sourceArnPrefix.map(value => value)
      )
    def discovererIdPrefix: Option[__string]
    def limit: Option[__integer]
    def nextToken: Option[__string]
    def sourceArnPrefix: Option[__string]
    def getDiscovererIdPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("discovererIdPrefix", discovererIdPrefix)
    def getLimit: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getSourceArnPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceArnPrefix", sourceArnPrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ) extends zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly {
    override val discovererIdPrefix: Option[__string] = scala
      .Option(impl.discovererIdPrefix())
      .map(value => zio.aws.schemas.model.primitives.__string(value))
    override val limit: Option[__integer] = scala
      .Option(impl.limit())
      .map(value => zio.aws.schemas.model.primitives.__integer(value))
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.schemas.model.primitives.__string(value))
    override val sourceArnPrefix: Option[__string] = scala
      .Option(impl.sourceArnPrefix())
      .map(value => zio.aws.schemas.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ): zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-schemas_2.13-5.17.153.3-sources.jar: zio/aws/schemas/model/ListDiscoverersRequest.scala <==
package zio.aws.schemas.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.schemas.model.primitives.{__integer, __string}
import scala.jdk.CollectionConverters._
final case class ListDiscoverersRequest(
    discovererIdPrefix: Option[__string] = None,
    limit: Option[__integer] = None,
    nextToken: Option[__string] = None,
    sourceArnPrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest = {
    import ListDiscoverersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
      .builder()
      .optionallyWith(discovererIdPrefix.map(value => value: java.lang.String))(
        _.discovererIdPrefix
      )
      .optionallyWith(limit.map(value => value: Integer))(_.limit)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(sourceArnPrefix.map(value => value: java.lang.String))(
        _.sourceArnPrefix
      )
      .build()
  }
  def asReadOnly: zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly =
    zio.aws.schemas.model.ListDiscoverersRequest.wrap(buildAwsValue())
}
object ListDiscoverersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.schemas.model.ListDiscoverersRequest =
      zio.aws.schemas.model.ListDiscoverersRequest(
        discovererIdPrefix.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value),
        sourceArnPrefix.map(value => value)
      )
    def discovererIdPrefix: Option[__string]
    def limit: Option[__integer]
    def nextToken: Option[__string]
    def sourceArnPrefix: Option[__string]
    def getDiscovererIdPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("discovererIdPrefix", discovererIdPrefix)
    def getLimit: ZIO[Any, AwsError, __integer] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getSourceArnPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("sourceArnPrefix", sourceArnPrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ) extends zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly {
    override val discovererIdPrefix: Option[__string] =
      scala.Option(impl.discovererIdPrefix()).map(value => value: __string)
    override val limit: Option[__integer] =
      scala.Option(impl.limit()).map(value => value: __integer)
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
    override val sourceArnPrefix: Option[__string] =
      scala.Option(impl.sourceArnPrefix()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.schemas.model.ListDiscoverersRequest
  ): zio.aws.schemas.model.ListDiscoverersRequest.ReadOnly = new Wrapper(impl)
}
